@@ -30,10 +30,10 @@ sub run ($self) {
     }
 
     if ( $self->whois->max_threads && $self->whois->threads >= $self->whois->max_threads ) {
-        push $self->whois->requests_queue->@*, $self if !defined $queue_idx;
+        push $queue->@*, $self if !defined $queue_idx;
     }
     elsif ( $self->whois->max_threads_server && $self->server->threads >= $self->whois->max_threads_server ) {
-        push $self->whois->requests_queue->@*, $self if !defined $queue_idx;
+        push $queue->@*, $self if !defined $queue_idx;
     }
     else {
         splice $queue->@*, $queue_idx, 1, () if defined $queue_idx;
@@ -145,8 +145,8 @@ sub _finish ( $self, $h, $status, $reason, $data_ref ) {
 
         delete $self->whois->requests->{ $self->id };
 
-        while ( my $request = shift $self->request->@* ) {
-            $request->[1]->( $request->[0], $res );
+        while ( my $cb = shift $self->request->@* ) {
+            $cb->($res);
         }
 
         for my $next_req ( $self->whois->requests_queue->@* ) {
