@@ -26,9 +26,12 @@ sub _build_status ($self) {
         return $WHOIS_STATUS_NO_CONTENT if !$self->raw || !length $self->raw->$*;
 
         # check for ban
-        for my $re ( $Pcore::Whois::Data::RATE_LIMIT_RE->@* ) {
-            if ( $self->raw->$* =~ $re ) {
-                return $WHOIS_STATUS_BANNED;
+        if ( my $re = $self->server->rate_limit_re ) {
+            return $WHOIS_STATUS_BANNED if $self->raw->$* =~ $re;
+        }
+        else {
+            for my $re ( $Pcore::Whois::Data::RATE_LIMIT_RE->@* ) {
+                return $WHOIS_STATUS_BANNED if $self->raw->$* =~ $re;
             }
         }
     }
