@@ -6,6 +6,7 @@ use Pcore::Whois::Data;
 has host       => ( is => 'ro', isa => Str, required => 1 );                      # whois host addr
 has req_format => ( is => 'ro', isa => Str, default  => qq[<: QUERY :>$CRLF] );
 has is_verisign   => ( is => 'ro', isa => Bool );
+has rate_limit_re => ( is => 'ro', isa => RegexpRef );
 has not_found_md5 => ( is => 'ro', isa => Str );
 
 has status  => ( is => 'ro', isa => Int,               default => 0,                      init_arg => undef );
@@ -24,7 +25,7 @@ sub validate ( $self, $whois, $tld, $cb ) {
     $whois->run_request(
         $self,
         "$Pcore::Whois::Data::NOT_AVAIL_DOMAIN.$tld",
-        sub ( $domain, $res ) {
+        sub ($res) {
             $self->{status} = $res->status;
 
             $self->{reason} = $res->reason;
@@ -55,7 +56,7 @@ sub get_request_content ( $self, $query ) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 18                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 19                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
